#[non_exhaustive]pub enum ResolveError {
Show 19 variants
Ignored(PathBuf),
NotFound(String),
MatchedAliasNotFound(String, String),
TsconfigNotFound(PathBuf),
TsconfigSelfReference(PathBuf),
IOError(IOError),
Builtin(String),
ExtensionAlias(String, String, PathBuf),
Specifier(SpecifierError),
JSON(JSONError),
InvalidModuleSpecifier(String, PathBuf),
InvalidPackageTarget(String, String, PathBuf),
PackagePathNotExported(String, PathBuf),
InvalidPackageConfig(PathBuf),
InvalidPackageConfigDefault(PathBuf),
InvalidPackageConfigDirectory(PathBuf),
PackageImportNotDefined(String, PathBuf),
Unimplemented(&'static str),
Recursion,
}Expand description
All resolution errors
thiserror is used to display meaningful error messages.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Ignored(PathBuf)
Ignored path
Derived from ignored path (false value) from browser field in package.json
{
"browser": {
"./module": false
}
}See https://github.com/defunctzombie/package-browser-field-spec#ignore-a-module
NotFound(String)
Module not found
MatchedAliasNotFound(String, String)
Matched alias value not found
TsconfigNotFound(PathBuf)
Tsconfig not found
TsconfigSelfReference(PathBuf)
Tsconfig’s project reference path points to it self
IOError(IOError)
Builtin(String)
Node.js builtin modules
This is an error due to not being a Node.js runtime.
The alias option can be used to resolve a builtin module to a polyfill.
ExtensionAlias(String, String, PathBuf)
All of the aliased extension are not found
Displays Cannot resolve 'index.mjs' with extension aliases 'index.mts' in ...
Specifier(SpecifierError)
The provided path specifier cannot be parsed
JSON(JSONError)
JSON parse error
InvalidModuleSpecifier(String, PathBuf)
InvalidPackageTarget(String, String, PathBuf)
PackagePathNotExported(String, PathBuf)
InvalidPackageConfig(PathBuf)
InvalidPackageConfigDefault(PathBuf)
InvalidPackageConfigDirectory(PathBuf)
PackageImportNotDefined(String, PathBuf)
Unimplemented(&'static str)
Recursion
Occurs when alias paths reference each other.
Implementations